@@ -4,10 +4,9 @@ import aiohttp
 import asyncio
 import ujson as json
 from uuid import UUID
-from typing import Union
 from .sockets import Wss
-from typing import BinaryIO
 from binascii import hexlify
+from typing import BinaryIO, Union
 from time import time as timestamp
 
 from ..lib import *
@@ -16,14 +15,17 @@ from ..lib.objects import *
 
 class SClient(Wss):
     def __init__(self, deviceId: str = None, Trace: bool = False):
-        self.Trace = Trace
         self.uid = None
+        self.sid = None
         self.secret = None
+        self.web_headers = None
+
+        self.Trace = Trace
         headers.deviceId = deviceId
-        Wss.__init__(self, client=self, ses=self.session, Trace=self.Trace)
+        Wss.__init__(self, client=self, Session=self.session, Trace=self.Trace)
+        
         self.deviceId = headers.Headers().deviceId
         self.headers = headers.Headers().headers
-        self.web_headers = headers.Headers().web_headers
         self.session = aiohttp.ClientSession()
 
     async def __aenter__(self) -> "SClient":
@@ -398,17 +400,22 @@ class SClient(Wss):
             else: return CommentList((await req.json())["commentList"]).CommentList
 
     async def send_message(self, chatId: str, message: str = None, messageType: int = 0, file: BinaryIO = None,
-                     fileType: str = None, replyTo: str = None, mentionUserIds: list = None, stickerId: str = None,
+                     fileType: str = None, replyTo: str = None, mentionUserIds: Union[list, str] = None, stickerId: str = None,
                      snippetLink: str = None, ytVideo: str = None, snippetImage: BinaryIO = None, embedId: str = None,
                      embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None,
                      embedImage: BinaryIO = None):
+                     
         if message is not None and file is None: message = message.replace("[@", "‎‏").replace("@]", "‬‭")
 
         mentions = []
         if mentionUserIds:
-            for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            if type(mentionUserIds) is list:
+                for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            mentions.append({"uid": mentionUserIds})
 
-        if embedImage: embedImage = [[100, self.upload_image(embedImage), None]]
+        if embedImage:
+            if type(embedImage) is not str: embedImage = [[100, self.upload_image(embedImage), None]]
+            embedImage = [[100, embedImage, None]]
 
         data = {
             "type": messageType,
@@ -464,7 +471,7 @@ class SClient(Wss):
                 data["mediaUhqEnabled"] = False
 
             else:
-                raise TypeError("")
+                raise TypeError(fileType)
 
             data["mediaUploadValue"] = base64.b64encode(file.read()).decode()
             data["attachedObject"] = None
@@ -814,3 +821,25 @@ class SClient(Wss):
         async with self.session.get(api(f"/g/s/user-profile/{userId}/comment/{commentId}"), headers=self.headers) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Comment(await req.json()).Comments
+
+    async def get_notifications(self, size: int = 25, pagingType: str = "t"):
+        async with self.session.get(api(f"/g/s/notification?pagingType={pagingType}&size={size}"), headers = self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return NotificationList(await req.json()).NotificationList
+
+    async def get_notices(self, start: int = 0, size: int = 25, type: str = "usersV2", status: int = 1):
+        async with self.session.get(api(f"/g/s/notice?type={type}&status={status}&start={start}&size={size}"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return NoticeList(await req.json()).NoticeList
+
+    async def accept_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        async with self.session.post(api(f"/g/s/notice/{requestId}/accept"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json(await req.json())
+    
+    async def decline_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        async with self.session.post(api(f"/g/s/notice/{requestId}/decline"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json(await req.json())
\ No newline at end of file
