@@ -4,23 +4,24 @@ import aiohttp
 import asyncio
 import ujson as json
 from uuid import UUID
-from typing import Union
+
 from time import timezone
-from typing import BinaryIO
-from binascii import hexlify
 from time import time as timestamp
+
+from binascii import hexlify
+from typing import Union, BinaryIO
 from json_minify import json_minify
 
 from ..lib import *
 from ..lib.objects import *
-
 class SLocal:
     def __init__(self, comId: str):
         self.comId = comId
         self.uid = headers.uid
+
+        self.session = aiohttp.ClientSession()
         self.headers = headers.Headers().headers
         self.web_headers = headers.Headers().web_headers
-        self.session = aiohttp.ClientSession()
 
     async def __aenter__(self) -> "SLocal":
         return self
@@ -133,14 +134,24 @@ class SLocal:
             if req.status != 200: return CheckExceptions(await req.json())
             else: return ThreadList((await req.json())["threadList"]).ThreadList
 
-    async def send_message(self, chatId: str, message: str = None, messageType: int = 0, file: BinaryIO = None, fileType: str = None, replyTo: str = None, mentionUserIds: list = None, stickerId: str = None, snippetLink: str = None, ytVideo: str = None, snippetImage: BinaryIO = None, embedId: str = None, embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None, embedImage: BinaryIO = None):
+    async def send_message(self, chatId: str, message: str = None, messageType: int = 0, file: BinaryIO = None,
+                     fileType: str = None, replyTo: str = None, mentionUserIds: Union[list, str] = None, stickerId: str = None,
+                     snippetLink: str = None, ytVideo: str = None, snippetImage: BinaryIO = None, embedId: str = None,
+                     embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None,
+                     embedImage: BinaryIO = None):
+
         if message is not None and file is None: message = message.replace("[@", "‎‏").replace("@]", "‬‭")
 
         mentions = []
         if mentionUserIds:
-            for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            if type(mentionUserIds) is list:
+                for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            mentions.append({"uid": mentionUserIds})
+
+        if embedImage:
+            if type(embedImage) is not str: embedImage = [[100, self.upload_image(embedImage, "image"), None]]
+            embedImage = [[100, embedImage, None]]
 
-        if embedImage: embedImage = [[100, self.upload_media(embedImage, "image"), None]]
 
         data = {
             "type": messageType,
@@ -196,7 +207,7 @@ class SLocal:
                 data["mediaUploadValueContentType"] = "image/gif"
                 data["mediaUhqEnabled"] = False
 
-            else: raise TypeError("")
+            else: raise TypeError(fileType)
 
             data["mediaUploadValue"] = base64.b64encode(file.read()).decode()
             data["attachedObject"] = None
@@ -222,7 +233,7 @@ class SLocal:
             data["message"]["mediaType"] = 100
             data["message"]["mediaValue"] = icon
 
-        async with self.session.post("https://aminoapps.com/api/add-chat-message", json=data, headers=self.web_headers) as req:
+        async with self.session.post(webApi("/add-chat-message"), json=data, headers=self.web_headers) as req:
             try:
                 if (await req.json())["code"] != 200: return CheckExceptions(await req.json())
                 else: Json(await req.json())
@@ -953,10 +964,38 @@ class SLocal:
 
     async def search_user(self, username: str, start: int = 0, size: int = 25):
         async with self.session.get(api(f"/x{self.comId}/s/user-profile?type=name&q={username}&start={start}&size={size}"),headers=self.headers) as req:
-            if req.status_code != 200: return CheckExceptions(await req.json())
+            if req.status != 200: return CheckExceptions(await req.json())
             else: return UserProfileList((await req.json())["userProfileList"]).UserProfileList
 
     async def search_blog(self, words: str, start: int = 0, size: int = 25):
         async with self.session.get(api(f"/x{self.comId}/s/blog?type=keywords&q={words}&start={start}&size={size}"),headers=self.headers) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             else: return BlogList((await req.json())["blogList"]).BlogList
+
+    async def get_notifications(self, size: int = 25, pagingType: str = "t"):
+        async with self.session.get(api(f"/x{self.comId}/s/notification?pagingType={pagingType}&size={size}"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return NotificationList(await req.json()).NotificationList
+
+    async def get_notices(self, start: int = 0, size: int = 25, type: str = "usersV2", status: int = 1):
+        async with self.session.get(api(f"/x{self.comId}/s/notice?type={type}&status={status}&start={start}&size={size}"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return NoticeList(await req.json()).NoticeList
+
+    async def accept_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        async with self.session.post(api(f"/x{self.comId}/s/notice/{requestId}/accept"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json(await req.json())
+    
+    async def decline_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        async with self.session.post(api(f"/x{self.comId}/s/notice/{requestId}/decline"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json(await req.json())
+
+    async def sendWebActive(self):
+        data = {"ndcId": self.comId}
+        async with self.session.post(webApi("/community/stats/web-user-active-time"), json=data, headers=self.web_headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return await req.json()
\ No newline at end of file
