@@ -1,17 +1,16 @@
-### sockets are edited sockets from libs: Amino-sockets // amino.py
+# those sockets are based on: Amino-Sockets / Amino.py
+# Modified by SirLez, zett.0, Bovonos
 
 import time
 import asyncio
-import aiohttp
 import threading
 import websockets
-from ..lib import *
+
 import ujson as json
-from typing import Union
-from typing import BinaryIO
+from typing import Union, BinaryIO
 from sys import _getframe as getframe
-from ..lib.objects import Event, Payload, UsersActions
-from ..lib.exception import CheckExceptions as exception
+
+from .lib import *
 
 class Callbacks:
     def __init__(self):
@@ -209,7 +208,7 @@ class Actions:
         self.chatId = chatId
         self.comId = comId
 
-    def default(self):
+    def sendDefaultAction(self):
         SetAction(self.socket, {
             "o": {"actions": ["Browsing"], "target": f"ndc://x{self.comId}/", "ndcId": int(self.comId),
                   "params": {"duration": 27605}, "id": "363483"}, "t": 306}).start()
@@ -231,7 +230,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.sendDefaultAction()
         return SetAction(self.socket, data)
 
     def Chatting(self, threadType: int = 2):
@@ -250,7 +249,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.sendDefaultAction()
         return SetAction(self.socket, data)
 
     def PublicChats(self):
@@ -265,7 +264,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.sendDefaultAction()
         return SetAction(self.socket, data)
 
     def LeaderBoards(self):
@@ -280,7 +279,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.sendDefaultAction()
         return SetAction(self.socket, data)
 
     def Custom(self, actions: Union[str, list], target: str, params: dict):
@@ -295,7 +294,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.sendDefaultAction()
         return SetAction(self.socket, data)
 
 
@@ -496,9 +495,9 @@ class WssClient:
         return Actions(self.wss, comId, chatId)
 
 class Wss(Callbacks, WssClient):
-    def __init__(self, client, ses, Trace):
+    def __init__(self, client, Session, Trace):
         self.client = client
-        self.ses = ses
+        self.ses = Session
 
         Callbacks.__init__(self)
         WssClient.__init__(self, self)
@@ -530,7 +529,7 @@ class Wss(Callbacks, WssClient):
         self.headers = {
             "NDCDEVICEID": self.client.deviceId,
             "NDCAUTH": self.client.sid,
-            "NDC-MSG-SIG": util.s(data=final)}
+            "NDC-MSG-SIG": util.generateSig(data=final)}
         try:
             async with websockets.connect(f"{self.socket_url}/?signbody={final.replace('|', '%7C')}", extra_headers=self.headers) as webs:
                 self.socket = webs
@@ -579,14 +578,14 @@ class Wss(Callbacks, WssClient):
 
         async with self.ses.post(f"{self.narvi}/g/s/media/upload", data=data, headers=headers) as response:
             if await response.json()["api:statuscode"] != 0:
-                return exception(await response.json())
+                return CheckExceptions(await response.json())
             else:
                 return await response.json()["mediaValue"]
 
     async def sendWebActive(self, comId: str):
         data = {"ndcId": comId}
-        async with self.ses.post("https://aminoapps.com/api/community/stats/web-user-active-time", json=data, headers=self.web_headers) as response:
+        async with self.ses.post(webApi("/community/stats/web-user-active-time"), json=data, headers=self.web_headers) as response:
             if await response.json()["code"] != 200:
-                return exception(await response.json())
+                return CheckExceptions(await response.json())
             else:
                 return await response
