@@ -1,31 +1,32 @@
 import os
+from uuid import UUID
+from requests import Session
 from binascii import hexlify
 from time import time as timestamp
-from typing import BinaryIO
-from typing import Union
-from uuid import UUID
+from typing import BinaryIO, Union
 
 import ujson as json
 
 from .lib import *
-from .lib import CheckExceptions
 from .lib.objects import *
 from .sockets import Wss
 
 
 class Client(Wss):
     def __init__(self, deviceId: str = None, proxies: dict = None, trace: bool = False):
+        self.uid = None
         self.sid = None
+        self.secret = None
         self.web_headers = None
+        
         self.trace = trace
         self.proxies = proxies
-        self.uid = None
-        self.secret = None
         headers.deviceId = deviceId
         Wss.__init__(self, self, trace=self.trace)
+
         self.deviceId = headers.Headers().deviceId
         self.headers = headers.Headers().headers
-        self.session = requests.Session()
+        self.session = Session()
 
     def change_lang(self, lang: str = "ar-SY"):
         headers.lang = lang
@@ -204,7 +205,7 @@ class Client(Wss):
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def get_my_communitys(self, start: int = 0, size: int = 25):
+    def get_my_communities(self, start: int = 0, size: int = 25):
         req = self.session.get(api(f"/g/s/community/joined?v=1&start={start}&size={size}"), headers=self.headers,
                                proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
@@ -440,17 +441,22 @@ class Client(Wss):
         return CommentList(req.json()["commentList"]).CommentList
 
     def send_message(self, chatId: str, message: str = None, messageType: int = 0, file: BinaryIO = None,
-                     fileType: str = None, replyTo: str = None, mentionUserIds: list = None, stickerId: str = None,
+                     fileType: str = None, replyTo: str = None, mentionUserIds: Union[list, str] = None, stickerId: str = None,
                      snippetLink: str = None, ytVideo: str = None, snippetImage: BinaryIO = None, embedId: str = None,
                      embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None,
                      embedImage: BinaryIO = None):
+                     
         if message is not None and file is None: message = message.replace("[@", "‎‏").replace("@]", "‬‭")
 
         mentions = []
         if mentionUserIds:
-            for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            if type(mentionUserIds) is list:
+                for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            mentions.append({"uid": mentionUserIds})
 
-        if embedImage: embedImage = [[100, self.upload_image(embedImage), None]]
+        if embedImage:
+            if type(embedImage) is not str: embedImage = [[100, self.upload_image(embedImage), None]]
+            embedImage = [[100, embedImage, None]]
 
         data = {
             "type": messageType,
@@ -885,3 +891,25 @@ class Client(Wss):
                                proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Comment(req.json()).Comments
+
+    def get_notifications(self, size: int = 25, pagingType: str = "t"):
+        req = self.session.get(api(f"/g/s/notification?pagingType={pagingType}&size={size}"), headers = self.headers, proxies = self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return NotificationList(req.json()).NotificationList
+    
+    def get_notices(self, start: int = 0, size: int = 25, type: str = "usersV2", status: int = 1):
+        req = self.session.get(api(f"/g/s/notice?type={type}&status={status}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return NoticeList(req.json()).NoticeList
+
+    def accept_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        req = self.session.post(api(f"/g/s/notice/{requestId}/accept"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Json(req.json())
+    
+    def decline_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        req = self.session.post(api(f"/g/s/notice/{requestId}/decline"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Json(req.json())
