@@ -1,7 +1,7 @@
 import json
-import sys
+from sys import version_info as version
 
-from .util import c, s, uu
+from .util import generateDevice, generateSig, uuidString
 
 uid = None
 sid = None
@@ -14,15 +14,14 @@ class Headers:
         if deviceId:
             self.deviceId = deviceId
         else:
-            self.deviceId = c()
+            self.deviceId = generateDevice()
 
-        version = sys.version_info
         self.headers = {
             "NDCDEVICEID": self.deviceId,
-            "AUID": uu(),
-            "SMDEVICEID": uu(),
+            "AUID": uuidString(),
+            "SMDEVICEID": uuidString(),
             "Content-Type": "application/json; charset=utf-8",
-            "User-Agent": f"python/{version.major}.{version.minor}.{version.micro} (python-requests/2.25; SAmino/2.3.1)",
+            "User-Agent": f"python/{version.major}.{version.minor}.{version.micro} (python-requests/2.25; SAmino/2.4.0)",
             "Host": "service.narvii.com",
             "Accept-Encoding": "gzip",
             "Connection": "Upgrade"
@@ -49,7 +48,7 @@ class Headers:
             if type(data) is not str:
                 data = json.dumps(data)
 
-            self.headers["NDC-MSG-SIG"] = s(data)
+            self.headers["NDC-MSG-SIG"] = generateSig(data)
 
         if lang:
             self.headers.update({"NDCLANG": lang[:lang.index("-")], "Accept-Language": lang})
