@@ -2,9 +2,9 @@ import os
 from binascii import hexlify
 from time import time as timestamp
 from time import timezone
-from typing import BinaryIO
-from typing import Union
+from typing import Union, BinaryIO
 from uuid import UUID
+from requests import Session
 
 import ujson as json
 from json_minify import json_minify
@@ -19,9 +19,10 @@ class Local:
         self.comId = comId
         self.uid = headers.uid
         self.sid = headers.sid
+
+        self.session = Session()
         self.headers = headers.Headers().headers
         self.web_headers = headers.Headers().web_headers
-        self.session = requests.Session()
 
     def get_video_rep_info(self, chatId: str):
         req = self.session.get(api(f"/x{self.comId}/s/chat/thread/{chatId}/avchat-reputation"), headers=self.headers,
@@ -133,17 +134,22 @@ class Local:
         return ThreadList(req.json()["threadList"]).ThreadList
 
     def send_message(self, chatId: str, message: str = None, messageType: int = 0, file: BinaryIO = None,
-                     fileType: str = None, replyTo: str = None, mentionUserIds: list = None, stickerId: str = None,
+                     fileType: str = None, replyTo: str = None, mentionUserIds: Union[list, str] = None, stickerId: str = None,
                      snippetLink: str = None, ytVideo: str = None, snippetImage: BinaryIO = None, embedId: str = None,
                      embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None,
                      embedImage: BinaryIO = None):
+
         if message is not None and file is None: message = message.replace("[@", "‎‏").replace("@]", "‬‭")
 
         mentions = []
         if mentionUserIds:
-            for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            if type(mentionUserIds) is list:
+                for mention_uid in mentionUserIds: mentions.append({"uid": mention_uid})
+            mentions.append({"uid": mentionUserIds})
 
-        if embedImage: embedImage = [[100, self.upload_media(embedImage, "image"), None]]
+        if embedImage:
+            if type(embedImage) is not str: embedImage = [[100, self.upload_image(embedImage, "image"), None]]
+            embedImage = [[100, embedImage, None]]
 
         data = {
             "type": messageType,
@@ -229,7 +235,7 @@ class Local:
             data["message"]["mediaType"] = 100
             data["message"]["mediaValue"] = icon
 
-        req = self.session.post("https://aminoapps.com/api/add-chat-message", json=data, headers=self.web_headers)
+        req = self.session.post(webApi("/add-chat-message"), json=data, headers=self.web_headers)
         try:
             if req.json()["code"] != 200: return CheckExceptions(req.json())
         except:
@@ -1095,7 +1101,7 @@ class Local:
             "timestamp": int(timestamp() * 1000)
         })
         req = self.session.post(api(f"/x{self.comId}/s/blog/{quizId}/quiz/result"),
-                                headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
+                            	headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return req.status_code
 
@@ -1116,3 +1122,87 @@ class Local:
                                headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         return BlogList(req.json()["blogList"]).BlogList
+
+    def get_notifications(self, size: int = 25, pagingType: str = "t"):
+        req = self.session.get(api(f"/x{self.comId}/s/notification?pagingType={pagingType}&size={size}"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return NotificationList(req.json()).NotificationList
+    
+    def get_notices(self, start: int = 0, size: int = 25, type: str = "usersV2", status: int = 1):
+        req = self.session.get(api(f"/x{self.comId}/s/notice?type={type}&status={status}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return NoticeList(req.json()).NoticeList
+
+    def accept_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        req = self.session.post(api(f"/x{self.comId}/s/notice/{requestId}/accept"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Json(req.json())
+    
+    def decline_promotion(self, requestId: str):
+        if not isinstance(requestId, str): raise Exception(f"Please use a string not {type(requestId)}")
+        req = self.session.post(api(f"/x{self.comId}/s/notice/{requestId}/decline"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Json(req.json())
+
+    def sendWebActive(self):
+        data = {"ndcId": self.comId}
+        req = self.session.post(webApi("/community/stats/web-user-active-time"), json=data, headers=self.web_headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return req.json()
+    
+     def get_recent_blogs(self, pageToken: str = None, start: int = 0, size: int = 25):
+        req = self.session.get(api(f"/x{self.comId}/s/feed/blog-all?pagingType=t&{f'pageToken={pageToken}' if pageToken else ''}&size={size}"), headers=self.headers, proxies=self.proxies)
+        return CheckExceptions(req.json()) if req.status_code != 200 else Json(req.json())
+
+    def publish_to_featured(self, time: int, userId: str = None, chatId: str = None, blogId: str = None, wikiId: str = None):
+        time = {
+            1: 3600,
+            2: 7200,
+            3: 10800
+        }.get(time) if chatId else {
+            1: 86400,
+            2: 172800,
+            3: 259200
+        }.get(time)
+
+        data = {
+            "adminOpName": 114,
+            "adminOpValue": {
+                "featuredDuration": time
+            },
+            "timestamp": int(timestamp() * 1000)
+        }
+
+        if userId: featuredType, endpoing = 4, f"user-profile/{userId}"
+        elif blogId: featuredType, endpoint = 1, f"blog/{blogId}"
+        elif wikiId: featuredType, endpoint = 1, f"item/{blogId}"
+        elif chatId: featuredType, endpoint = 5, f"chat/thread/{chatId}"
+        else: raise TypeError("Please Specify Object ID")
+
+        data["adminOpValue"]["featuredType"] = featuredType
+        data = json.dumps(data)
+        req = self.session.post(f"{self.api}/x{self.comId}/s/{endpoint}/admin", headers=headers.Headers(data=data).headers, data=data, proxies=self.proxies)
+        return CheckExceptions(req.json()) if req.status_code != 200 else Json(req.json())
+
+    def remove_from_featured(self, userId: str = None, chatId: str = None, blogId: str = None, wikiId: str = None):
+        data = {
+            "adminOpName": 114,
+            "adminOpValue": {
+                "featuredType": 0
+            },
+            "timestamp": int(timestamp() * 1000)
+        }
+
+        if userId: endpoint = f"user-profile/{userId}"
+        elif blogId: endpoint = f"blog/{blogId}"
+        elif wikiId: endpoint = f"item/{blogId}"
+        elif chatId:  endpoint = f"chat/thread/{chatId}"
+        else: raise TypeError("Please Specify Object ID")
+
+        data["adminOpValue"]["featuredType"] = featuredType
+        data = json.dumps(data)
+        req = self.session.post(f"{self.api}/x{self.comId}/s/{endpoint}/admin", headers=headers.Headers(data=data).headers, data=data, proxies=self.proxies)
+        return CheckExceptions(req.json()) if req.status_code != 200 else Json(req.json())
+
+
