@@ -1,18 +1,17 @@
-# those sockets are based on: Amino-Sockets / Amino.py
+# those sockets are based on: Amino-Sockets & Amino.py
 # Modified by SirLez, zett.0, Bovonos
+
 import threading
 import time as timer
 from sys import _getframe as getframe
-from typing import BinaryIO
-from typing import Union
+from typing import Union, BinaryIO
 
 import requests
 import ujson as json
 import websocket
 
-from .lib import util, headers
-from .lib.exception import CheckExceptions as exception
-from .lib.objects import Event, Payload, UsersActions
+from .lib import *
+from .lib.objects import *
 
 
 class Callbacks:
@@ -209,7 +208,7 @@ class Actions:
         self.chatId = chatId
         self.comId = comId
 
-    def default(self):
+    def setDefaultAction(self):
         """
         Default Browsing
         """
@@ -222,16 +221,16 @@ class Actions:
         Send Browsing Action
 
         **Parameters**
-            - **blogId**: 2 For Public 1 & 0 For Private (str)
+            - **blogId**: target blogId (str)
             - **blogType**: Type Of the Blog *poll & blog & wiki* (int)
 
         **Return**
             - **SetAction**:  (Class)
         """
+        target = f"ndc://x{self.comId}/featured"
+
         if blogId and blogType:
             target = f"ndc://x{self.comId}/blog/"
-        else:
-            target = f"ndc://x{self.comId}/featured"
 
         data = {
             "o": {
@@ -243,10 +242,10 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.setDefaultAction()
         return SetAction(self.socket, data)
 
-    def Chatting(self, threadType: int = 2):
+    def Chatting(self, threadId: str = None, threadType: int = 2):
         """
         Send Chatting Action
 
@@ -256,6 +255,7 @@ class Actions:
         **Return**
             - **SetAction**:  (Class)
         """
+
         data = {
             "o": {
                 "actions": ["Chatting"],
@@ -264,13 +264,14 @@ class Actions:
                 "params": {
                     "duration": 12800,
                     "membershipStatus": 1,
-                    "threadType": threadType
+                    "threadType": threadType,
+                    "threadId": threadId
                 },
                 "id": "1715976"
             },
             "t": 306
         }
-        self.default()
+        # self.defaultData()
         return SetAction(self.socket, data)
 
     def PublicChats(self):
@@ -290,7 +291,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.setDefaultAction()
         return SetAction(self.socket, data)
 
     def LeaderBoards(self):
@@ -310,7 +311,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.setDefaultAction()
         return SetAction(self.socket, data)
 
     def Custom(self, actions: Union[str, list], target: str, params: dict):
@@ -335,7 +336,7 @@ class Actions:
             },
             "t": 306
         }
-        self.default()
+        self.setDefaultAction()
         return SetAction(self.socket, data)
 
 
@@ -580,20 +581,22 @@ class WssClient:
         return UsersActions(data={}).UsersActions
 
     def actions(self, comId: str, chatId: str):
-        threading.Thread(target=self.wss.sendWebActive, args=(comId,)).start()
+        # threading.Thread(target=self.wss.sendWebActive, args=(comId,)).start()
         return Actions(self.wss, comId, chatId)
 
 
 class Wss(Callbacks, WssClient):
     def __init__(self, client, trace: bool = False):
 
+        self.trace = trace
         self.socket = None
         self.headers = None
         self.client = client
-        self.trace = trace
         self.isOpened = False
+
         Callbacks.__init__(self)
         WssClient.__init__(self, self)
+        
         self.narvi = "https://service.narvii.com/api/v1/"
         self.socket_url = "wss://ws1.narvii.com"
         self.lastMessage = {}
@@ -624,7 +627,7 @@ class Wss(Callbacks, WssClient):
         self.headers = {
             "NDCDEVICEID": self.client.deviceId,
             "NDCAUTH": self.client.sid,
-            "NDC-MSG-SIG": util.s(data=final)}
+            "NDC-MSG-SIG": util.generateSig(data=final)}
         self.socket = websocket.WebSocketApp(f"{self.socket_url}/?signbody={final.replace('|', '%7C')}",
                                              on_message=self.on_message,
                                              on_close=self.onClose,
@@ -656,14 +659,13 @@ class Wss(Callbacks, WssClient):
 
         response = requests.post(f"{self.narvi}/g/s/media/upload", data=data, headers=headers)
         if response.json()["api:statuscode"] != 0:
-            return exception(response.json())
+            return CheckExceptions(response.json())
         return response.json()["mediaValue"]
 
     def sendWebActive(self, comId: str):
         data = {"ndcId": comId}
-        response = requests.post("https://aminoapps.com/api/community/stats/web-user-active-time", json=data,
-                                 headers=headers.Headers().web_headers)
-        if response.json()["code"] != 200:
-            return exception(response.json())
 
-        return response
+        response = requests.post(util.webApi("/community/stats/web-user-active-time"), json=data, headers=headers.Headers().web_headers)
+        if response.status_code != 200: return CheckExceptions(response.json())
+
+        return response.json()
